<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Image</source>
      <translation>Immagine</translation>
    </message>
    <message>
      <source>Create image plane...</source>
      <translation>Crea un piano immagine...</translation>
    </message>
    <message>
      <source>Create a planar image in the 3D space</source>
      <translation>Create a planar image in the 3D space</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation>crea un'immagine piana nello spazio 3D</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <source>Image</source>
      <translation>Immagine</translation>
    </message>
    <message>
      <source>Open...</source>
      <translation>Apri...</translation>
    </message>
    <message>
      <source>Open image view</source>
      <translation>Apri il visualizzatore di immagini</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+308"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>Tipo di spazio colore indefinito per la visualizzazione delle immagini</translation>
    </message>
    <message>
      <source>Image pixel format</source>
      <translation>Formato pixel</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+77"/>
      <source>&amp;Fit image</source>
      <translation>&amp;Adatta immagine</translation>
    </message>
    <message>
      <source>Stretch the image to fit the view</source>
      <translation>Stira l'immagine per adattarsi alla vista</translation>
    </message>
    <message>
      <source>&amp;1:1 scale</source>
      <translation>Scala &amp;1:1</translation>
    </message>
    <message>
      <source>Display the image at a 1:1 scale</source>
      <translation>Visualizza l'immagine in scala 1:1</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation>Colori &amp;originali</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation>Visualizza l'immagine con i suoi colori originali</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation>&amp;Colori più luminosi</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation>Visualizza l'immagine con colori più luminosi</translation>
    </message>
    <message>
      <source>Standard</source>
      <translation>Standard</translation>
    </message>
    <message>
      <source>Ready...</source>
      <translation>Pronto...</translation>
    </message>
    <message>
      <source>grey</source>
      <translation>grigio</translation>
    </message>
    <message>
      <source>zoom</source>
      <translation>zoom</translation>
    </message>
    <message>
      <source>outside image</source>
      <translation>fuori dall'immagine</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation>Visualizzatore di immagini</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="+106"/>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Immagini (*.png *.xpm *.jpg *.bmp)</translation>
    </message>
    <message>
      <source>Choose an image file to open</source>
      <translation>Seleziona un file immagine da aprire</translation>
    </message>
    <message>
      <source>Images</source>
      <translation>Images</translation>
    </message>
    <message>
      <source>All files</source>
      <translation>All files</translation>
    </message>
    <message>
      <source>Error open image</source>
      <translation>Errore durante l'apertura dell'immagine</translation>
    </message>
    <message>
      <source>Could not load the choosen image</source>
      <translation>Impossibile caricare l'immagine scelta</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>Immagine</translation>
    </message>
  </context>
</TS>
